@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.19 2004/09/30 12:34:11 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/main.c,v 1.20 2004/10/16 00:40:11 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -561,9 +561,11 @@ static RETSIGTYPE failover_handler(int sig)
 	if (switching)
 		return;
 
+#ifdef NOT_USED
 	/* secondary backend exists? */
 	if (pool_config.secondary_backend_port == 0)
 		return;
+#endif
 
 	/* already failover */
 	if (strcmp(pool_config.current_backend_host_name, pool_config.secondary_backend_host_name) ||
@@ -578,7 +580,7 @@ static RETSIGTYPE failover_handler(int sig)
 					   pool_config.secondary_backend_host_name,
 					   pool_config.secondary_backend_port);
 		}
-		else
+		else if (pool_config.secondary_backend_port != 0)
 		{
 			pool_log("starting failover from %s(%d) to %s(%d)",
 					   pool_config.current_backend_host_name,
@@ -586,6 +588,10 @@ static RETSIGTYPE failover_handler(int sig)
 					   pool_config.secondary_backend_host_name,
 					   pool_config.secondary_backend_port);
 		}
+		else
+		{
+			pool_log("restarting pgpool");
+		}
 
 		/* kill all children */
 		for (i = 0; i < pool_config.num_init_children; i++)
@@ -605,7 +611,7 @@ static RETSIGTYPE failover_handler(int sig)
 			/* disable replicaton mode */
 			pool_config.replication_enabled = 0;
 		}
-		else
+		else if (pool_config.secondary_backend_port != 0)
 		{
 			/* fail over to secondary */
 			pool_config.current_backend_host_name = pool_config.secondary_backend_host_name;
@@ -631,7 +637,7 @@ static RETSIGTYPE failover_handler(int sig)
 					   pool_config.secondary_backend_host_name,
 					   pool_config.secondary_backend_port);
 		}
-		else
+		else if (pool_config.secondary_backend_port != 0)
 		{
 			pool_log("failover from %s(%d) to %s(%d) done.",
 					   pool_config.backend_host_name,
@@ -639,6 +645,10 @@ static RETSIGTYPE failover_handler(int sig)
 					   pool_config.secondary_backend_host_name,
 					   pool_config.secondary_backend_port);
 		}
+		else
+		{
+			pool_log("restarting pgpool done.");
+		}
 	}
 }
 
