@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.23 2004/09/13 00:05:10 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.24 2004/09/30 12:34:11 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -111,7 +111,7 @@ typedef struct CancelPacket
  * configuration paramters
  */
 typedef struct {
-    int	inetdomain;	/* should we make an INET domain socket too? */
+	char *listen_addresses; /* hostnames/IP addresses to listen on */
     int	port;	/* port # to bind */
 	char *socket_dir;		/* pgpool socket directory */
     char	*backend_host_name;	/* backend host name */
