@@ -1,6 +1,6 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.23 2004/07/19 01:28:44 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool_connection_pool.c,v 1.24 2004/08/18 07:05:17 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -178,17 +178,15 @@ POOL_CONNECTION_POOL *pool_create_cp(void)
 	free(MASTER_CONNECTION(p)->sp->database);
 	free(MASTER_CONNECTION(p)->sp->startup_packet);
 	pool_close(MASTER_CONNECTION(p)->con);
-	memset(p, 0, sizeof(POOL_CONNECTION_POOL));
 
 	if (pool_config.replication_enabled)
 	{
-		free(SECONDARY_CONNECTION(p)->sp->user);
-		free(SECONDARY_CONNECTION(p)->sp->database);
-		free(SECONDARY_CONNECTION(p)->sp->startup_packet);
+		/* do not free memory! we did not allocate them */
 		pool_close(SECONDARY_CONNECTION(p)->con);
-		memset(p, 0, sizeof(POOL_CONNECTION_POOL));
 	}
 
+	memset(p, 0, sizeof(POOL_CONNECTION_POOL));
+
 	return new_connection(p);
 }
 
@@ -265,16 +263,14 @@ RETSIGTYPE pool_backend_timer_handler(int sig)
 				free(MASTER_CONNECTION(p)->sp->database);
 				free(MASTER_CONNECTION(p)->sp->startup_packet);
 				pool_close(MASTER_CONNECTION(p)->con);
-				memset(p, 0, sizeof(POOL_CONNECTION_POOL));
 
 				if (pool_config.replication_enabled)
 				{
-					free(SECONDARY_CONNECTION(p)->sp->user);
-					free(SECONDARY_CONNECTION(p)->sp->database);
-					free(SECONDARY_CONNECTION(p)->sp->startup_packet);
+					/* do not free memory! we did not allocate them */
 					pool_close(SECONDARY_CONNECTION(p)->con);
-					memset(p, 0, sizeof(POOL_CONNECTION_POOL));
 				}
+
+				memset(p, 0, sizeof(POOL_CONNECTION_POOL));
 			}
 			else
 			{
